@@ -10,7 +10,10 @@ from types import ModuleType
 
 import requests
 import inspect
-from loguru import logger
+# Удаляем логуру
+# from loguru import logger
+# Используем наш логгер
+from shadowstep.utils import get_logger
 from typing import Union, List, Optional, Set
 
 from appium.options.android import UiAutomator2Options
@@ -47,6 +50,8 @@ class WebDriverSingleton(WebDriver):
 
     @classmethod
     def _get_session_id(cls, kwargs):
+        # Получаем логгер для текущего класса
+        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         res = requests.get(kwargs['command_executor'] + '/sessions')
         res_json = json.loads(res.text)
@@ -58,6 +63,8 @@ class WebDriverSingleton(WebDriver):
     @classmethod
     def clear_instance(cls):
         """Удаляет текущий экземпляр и очищает ресурсы WebDriverSingleton."""
+        # Получаем логгер для текущего класса
+        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         cls._driver = None
         cls._instance = None  # Убирает ссылку на экземпляр для высвобождения памяти
@@ -72,6 +79,8 @@ class WebDriverSingleton(WebDriver):
             WebDriver
                 The current WebDriver instance.
         """
+        # Получаем логгер для текущего класса
+        logger = get_logger(f"{__name__}.{cls.__name__}")
         logger.debug(f"{inspect.currentframe().f_code.co_name}")
         return cls._driver
 
@@ -79,7 +88,8 @@ class WebDriverSingleton(WebDriver):
 class ShadowstepBase:
 
     def __init__(self):
-        self.logger = logger
+        # Используем стандартный логгер
+        self.logger = get_logger(f"{__name__}.{self.__class__.__name__}")
         self.driver: WebDriver = None
         self.server_ip: str = None
         self.server_port: int = None
